pub enum ServerResponse {
StartRecording(RecordingActionResult),
StopRecording(RecordingActionResult),
}Variants
StartRecording(RecordingActionResult)
StopRecording(RecordingActionResult)
Implementations
Sourceimpl ServerResponse
impl ServerResponse
const ENTRIES: &'static [EnvelopeEntry<Self>]
Sourcepub fn into_envelope(self, response_to: RequestId) -> Result<Envelope, Error>
pub fn into_envelope(self, response_to: RequestId) -> Result<Envelope, Error>
encode one server response into the Odoo wire envelope
Errors
returns an error when the typed payload cannot be serialized into the JSON envelope payload
pub(crate) fn decode( tag: &str, payload: Option<Value>, ) -> Result<Self, EnvelopeDecodeError>